@@ -8,9 +8,12 @@
  *   (at your option) any later version.                                   *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "circuitdocument.h"
 #include "circuitview.h"
-#include "config.h"
 #include "ktechlab.h"
 #include "simulator.h"
 #include "viewiface.h"
